#pylint: disable=line-too-long
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
'''
    The format between %addon is strictly prescribed
     so we are putting the make/parse functions together in hopes
     that maintance is easier that way
'''
from __future__ import unicode_literals
from __future__ import absolute_import

from org_scientificlinux_contexts.constants import DEFAULT_CONTEXT_URL, DEFAULT_ENABLE_TESTING, IFS

from pykickstart.errors import KickstartParseError

def makeline(context, default_url=DEFAULT_CONTEXT_URL, default_testing=DEFAULT_ENABLE_TESTING):
    '''
        Generate the text that goes within our %addon block

        :param context: The Context object to present
        :type context: org_scientificlinux_contexts.Context

        :param default_testing: Is the default url our default and therefore omitable?
        :type default_testing: str
        :default default_testing: org_scientificlinux_contexts.constants.DEFAULT_CONTEXT_URL

        :param default_testing: Is testing enabled by default and therefore omitable?
        :type default_testing: boolean
        :default default_testing: org_scientificlinux_contexts.constants.DEFAULT_ENABLE_TESTING
    '''
    if context == None:
        return ''

    url = ''
    if context.url != default_url:
        url = "%s%s" % (context.url, IFS)

    name = context.name

    testing = ''
    if context.enable_testing:
        if not default_testing:
            # testing is NOT the default case, so be explicit
            testing = "%stesting" % IFS

    return url + name + testing + '\n'

def readline(text):
    '''
        Return a Context object based on a line of %addon

        :param line: A single line of our %addon section
        :type line: str

        :returns: The Context object present
        :rtype: org_scientificlinux_contexts.Context or None
    '''
    from org_scientificlinux_contexts import Context

    if not text:
        return None

    text = text.lstrip().rstrip()
    line = text.split(IFS)

    opts = []
    for item in line:
        opts.append(item.lstrip().rstrip())

    # honor comment characters and ignore blank lines
    if text == '' or text.startswith('#') or len(opts) == 0:
        return None

    if len(opts) == 1:
        return Context(opts[0].lstrip().rstrip())


    elif len(opts) == 3:
        if opts[0] == '':
            # url was passed, but passed as empty
            opts[0] = DEFAULT_CONTEXT_URL
        if opts[2] == '#testing':
            return Context(url=opts[0], name=opts[1])
        else:
            return Context(url=opts[0], name=opts[1], enable_testing=True)


    elif len(opts) == 2:
        if opts[0] == '':
            # url was passed, but passed as empty
            opts[0] = DEFAULT_CONTEXT_URL

        if opts[1] == 'testing':
            return Context(name=opts[0], enable_testing=True)
        elif opts[1] == '#testing':
            return Context(name=opts[0])
        else:
            return Context(url=opts[0], name=opts[1])


    # Should be impossible to get here with sane values
    raise KickstartParseError("Unknown value found : %s" % text)


